% ztran.m - evaluates z-transform of a finite-duration signal
%
% Usage: X = ztran(x,z);
%
% x = length-L signal x = [x(0),x(1),...,x(L-1)], (can be entered as column or row)
% z = vector of non-zero complex numbers, (can be entered as column or row or matrix)
%
% X = polynomial X(z) evaluated at the matrix of z's, same size as z
%
% notes: uses Hoerner's rule
%
%        has the same output as X = polyval(flip(x),1./z)
%
%        does not check if any of the z's are zero
%
%        dtft can be implemented as dtft(x,w) = ztran(x,exp(j*w));
%
% see also dtft, fresp

function X = ztran(x,z)

if nargin==0, help ztran; return; end

[K,L] = size(z);

x = x(:);                     %  make x,z into columns
z = z(:);                     

z = 1./z;                           

X = 0;          
                
for n = length(x):-1:1,       % polynomial evaluation using Hoerner's rule
    X = x(n) + z .* X;       
end

X = reshape(X,K,L);           % reshape output to the shape of z

